@@ -40,7 +40,12 @@ sub get {
 sub post {
 	my $self   = shift;
 	my $params = $self->_prep_args([qw/method request_params/], @_);
-	my $url    = $self->_build_url(method => $params->{method});
+	while (my ($key, $val) = each(%{$params->{request_params}})) {
+		if (ref($val) eq 'HASH') {
+			$params->{request_params}{$key} = $self->json->encode($val);
+		}
+	}
+	my $url = $self->_build_url(method => $params->{method});
 	return $self->_handle_response(
 		$self->http->post_form($url, $params->{request_params}),
 	);
@@ -51,6 +56,7 @@ sub post {
 ##########
 
 sub http {return shift->{_http_handler}}
+
 sub json {return shift->{_json_handler}}
 
 #############
@@ -90,6 +96,11 @@ sub _handle_response {
 	my $status  = $response->{status};
 	my $content = $response->{content} || '[UNKNOWN CONTENT]';
 	my $reason  = $response->{reason}  || '[UNKNOWN REASON]';
+	if ($status == 400) {
+		if ($content =~ m/Bad Request: (.*) is missing\./) {
+			die "[$1] is a required parameter\n";
+		}
+	}
 	die "ERROR! Status [$status] Content [$content] reason [$reason]\n";
 }
 
